OVD KINEGRAM ScanSDK for Flutter

OVD KINEGRAM ScanSDK is a powerful SDK that enables developers to integrate scanning functionalities into their Flutter applications.

The SDK supports the scanning of various objects, such as

Supported Number Plates

ScanSDK has been trained to recognize license plates from Switzerland, UK, and the EU in accordance with EU Council Regulation (EC) No 2411/98.

Supported Barcode Formats

Linear product Linear industrial Matrix
UPC-A Code 39 QR Code
UPC-E Code 93 Micro QR Code
EAN-8 Code 128 rMQR Code
EAN-13 Codabar Aztec
DataBar DataBar Expanded DataMatrix
DX Film Edge PDF417
ITF MaxiCode (partial)

Quick Start

  1. Add the plugin to your pubspec.yaml:
dependencies:
  …

  scansdk:
    git:
      url: git@github.com:OVD-Kinegram-AG/scan-sdk-flutter.git
      ref: main
  1. Import the plugin with import 'package:scansdk/scansdk.dart';.
  2. Create a ScanSDK instance.
  3. Call openScanner() and handle the returned ScanSdkResult objects.
final ScanSDK _scanSdk = ScanSDK();

Future<void> _openScanner() async {
  final results = await _scanSdk.openScanner();
  for (final result in results) {
    debugPrint('${result.type}: ${result.message}');
  }
}

Check example/lib/main.dart for a complete Flutter app.