ScanSDKPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ScanSDKPlatform
Implementers

Constructors

ScanSDKPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openScanner() Future<List<Map<String, dynamic>>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ScanSDKPlatform
getter/setter pair